(herald "Electronic Purchase with Money Order Protocol Variant"
  (comment "This version includes account numbers in exchanges"))

(comment "CPSA 2.2.0")
(comment "All input read")

(defprotocol epmo_acctnum basic
  (defrole bank
    (vars (b c m name) (acctnum text) (hash name) (nc nm nb price text))
    (trace (recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (recv (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (annotations b
      (1
        (forall ((pm name))
          (implies
            (and (authtransfer c acctnum b price pm nm)
              (reqtransfer pm b price pm nm))
            (dotransfer acctnum b price pm nm))))
      (2
        (and (says c (authtransfer c acctnum b price m nm))
          (says m (reqtransfer m b price m nm))))))
  (defrole customer
    (vars (b c m hash name) (acctnum nb nc nm goods price text))
    (trace (send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb)))
    (non-orig (privk b) (privk hash))
    (uniq-orig nc)
    (annotations c
      (1
        (says m
          (implies
            (exists ((acctnum2 text))
              (dotransfer acctnum2 b price m nm)) (doship m goods c))))
      (3
        (says b
          (forall ((pm name))
            (implies
              (and (authtransfer c acctnum b price m nm)
                (reqtransfer pm b price pm nm))
              (dotransfer acctnum b price pm nm)))))
      (4 (authtransfer c acctnum b price m nm))))
  (defrole merchant
    (vars (b c m hash name) (nb nc nm goods price text))
    (trace (recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    (non-orig (privk hash))
    (uniq-orig nm)
    (annotations m
      (1
        (implies
          (exists ((acctnum2 text)) (dotransfer acctnum2 b price m nm))
          (doship m goods c)))
      (2
        (and
          (says b
            (forall ((pm name))
              (exists ((acctnum2 text))
                (implies
                  (and (authtransfer c acctnum2 b price m nm)
                    (reqtransfer pm b price pm nm))
                  (dotransfer acctnum2 b price pm nm)))))
          (says c
            (exists ((acctnum2 text))
              (authtransfer c acctnum2 b price m nm)))))
      (3 (and (reqtransfer m b price m nm) (doship m goods c))))))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price text) (b m c hash name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nc nb)
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m)))))
  (label 0)
  (unrealized (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum text) (b m c hash name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (precedes ((0 1) (1 0)) ((1 1) (0 2)))
  (non-orig (privk b) (privk m) (privk c) (privk hash))
  (uniq-orig nm nc nb)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b)) (0 2))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))))
  (label 1)
  (parent 0)
  (unrealized (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum acctnum-0 goods-0 text)
    (b m c hash b-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 3) nm (1 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0)))))
  (label 2)
  (parent 1)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 text) (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nm
    (1 0) (enc nc nm m price (pubk c))
    (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))))
  (label 3)
  (parent 2)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((0 1) (3 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (1 0)) ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand bank 2) nm (1 0)
    (enc nc nm m price (pubk c))
    (enc c nc nm acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nm acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 4)
  (parent 2)
  (seen 8)
  (unrealized (0 0) (0 2) (1 0) (3 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods text) (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))))
  (label 5)
  (parent 3)
  (seen 9)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 nm-0 price-0 text)
    (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 6)
  (parent 3)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm acctnum-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm acctnum-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb acctnum-0)
  (operation nonce-test (displaced 4 2 customer 3) nm (3 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb acctnum-0 (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum-0 price (pubk hash))
            (privk b)) (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc acctnum-0 m price (pubk c)))
      (send (enc c nc acctnum-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc acctnum-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 7)
  (parent 4)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 3) nm (3 0)
    (enc nc nm m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nm acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 8)
  (parent 4)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 1)) ((1 1) (2 3)) ((2 0) (0 0)) ((2 2) (1 0))
    ((2 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 9)
  (parent 5)
  (unrealized)
  (shape))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods nm-0 price-0 text)
    (m c hash b name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (3 0)) ((2 2) (1 0))
    ((3 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm-0 m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 10)
  (parent 6)
  (seen 15)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm acctnum)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) acctnum
    (1 0) (enc "hash" c nc nb-0 acctnum price (pubk hash-0))
    (enc nc acctnum m price (pubk c))
    (enc c nc acctnum acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 11)
  (parent 7)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 4 3 bank 2) acctnum-0 (1 0)
    (enc "hash" c nc nb-0 acctnum-0 price (pubk hash-0))
    (enc nc acctnum-0 m price (pubk c))
    (enc c nc acctnum-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 12)
  (parent 7)
  (seen 20)
  (unrealized (0 0) (0 2) (1 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 nb-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nm
    (1 0) (enc "hash" c nc nb-0 nm price (pubk hash-0))
    (enc nc nm m price (pubk c)) (enc c nc nm acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 13)
  (parent 8)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 nb-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 4 3 bank 2) nm (1 0)
    (enc "hash" c nc nb-0 nm price (pubk hash-0))
    (enc nc nm m price (pubk c))
    (enc c nc nm acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 14)
  (parent 8)
  (seen 25)
  (unrealized (0 0) (0 2) (1 0))
  (comment "4 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price nm-0 price-0 acctnum goods text)
    (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (0 0)) ((3 0) (2 0))
    ((3 2) (1 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 15)
  (parent 10)
  (seen 9)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 16)
  (parent 11)
  (seen 26)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm acctnum)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb acctnum nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 17)
  (parent 11)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 18)
  (parent 12)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (3 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 19)
  (parent 12)
  (seen 31)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 20)
  (parent 12)
  (unrealized (0 0) (0 2) (1 0) (3 3))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods nb-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c))))))
  (label 21)
  (parent 13)
  (seen 34)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb goods price acctnum goods-0 nb-0 nm-0 price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 22)
  (parent 13)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nb-0
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 23)
  (parent 14)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 nb-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 0) (0 0))
    ((2 2) (3 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 24)
  (parent 14)
  (seen 31 39)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 25)
  (parent 14)
  (unrealized (0 0) (0 2) (1 0) (3 3))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 acctnum goods text) (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 26)
  (parent 16)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb acctnum nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 27)
  (parent 17)
  (seen 43)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 28)
  (parent 18)
  (seen 44)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 29)
  (parent 18)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 3 bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 30)
  (parent 19)
  (seen 47)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 2 customer 3) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 31)
  (parent 19)
  (seen 49)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (3 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 32)
  (parent 20)
  (seen 51)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 4 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (3 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 33)
  (parent 20)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price nb-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nm nc nb)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 34)
  (parent 21)
  (seen 9)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price acctnum goods nb-0 nm-0 price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm-0 m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c)))))
  (label 35)
  (parent 22)
  (seen 55)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 36)
  (parent 23)
  (seen 56)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 37)
  (parent 23)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 nb-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 3 bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 38)
  (parent 24)
  (seen 59)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 goods-0 nb-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 39)
  (parent 24)
  (seen 61)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (3 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 40)
  (parent 25)
  (seen 51 63)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 4 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (3 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 41)
  (parent 25)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (2 1)) ((1 1) (2 3)) ((2 0) (0 0)) ((2 2) (1 0))
    ((2 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation generalization deleted (2 0))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 42)
  (parent 26)
  (seen 9)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nm price-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 43)
  (parent 27)
  (unrealized)
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods text) (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum price (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 44)
  (parent 28)
  (seen 42)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 45)
  (parent 29)
  (seen 68)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 46)
  (parent 30)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 47)
  (parent 30)
  (unrealized (0 0) (0 2) (1 0) (4 3))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 48)
  (parent 31)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 49)
  (parent 31)
  (seen 33)
  (unrealized (0 0) (0 2) (1 0) (4 3))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 2 bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 50)
  (parent 32)
  (seen 73)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 3 customer 3) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 51)
  (parent 32)
  (seen 33 50)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 52)
  (parent 33)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 1) (3 3))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 53)
  (parent 33)
  (seen 72 77)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 54)
  (parent 33)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nm nc nb price nb-0 nm-0 price-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nm) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nm) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm-0) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nm)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nm nc nb nm-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nm price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nm (pubk hash)) (privk m))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nm acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nm price (pubk hash-0)) (privk b))
          (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm-0 m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nm m price (pubk c)))
      (send (enc c nc nm acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nm price (pubk hash)) (privk b))
          nb))))
  (label 55)
  (parent 35)
  (seen 15)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 acctnum goods text) (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 56)
  (parent 36)
  (seen 9)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (4 0)) ((2 2) (3 0))
    ((3 1) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 57)
  (parent 37)
  (seen 84)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nb-0
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 58)
  (parent 38)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 59)
  (parent 38)
  (unrealized (0 0) (0 2) (1 0) (4 3))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nb-0
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 60)
  (parent 39)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb-0 (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 61)
  (parent 39)
  (seen 41)
  (unrealized (0 0) (0 2) (1 0) (4 3))
  (comment "3 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 5 2 bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 62)
  (parent 40)
  (seen 89)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 63)
  (parent 40)
  (seen 41 62)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 64)
  (parent 41)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (4 0)) ((1 1) (0 2)) ((2 1) (3 3))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 65)
  (parent 41)
  (seen 77 88 93)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 66)
  (parent 41)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nm price-0 acctnum goods text) (c hash b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (3 1)) ((1 1) (3 3)) ((2 1) (0 0)) ((3 0) (2 0))
    ((3 2) (1 0)) ((3 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation generalization deleted (2 0))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 67)
  (parent 43)
  (seen 42)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nm price-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum price (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 68)
  (parent 45)
  (seen 67)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 69)
  (parent 46)
  (seen 100)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 70)
  (parent 46)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 71)
  (parent 47)
  (seen 104)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 72)
  (parent 47)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 3 bank 2)
    (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-1)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 73)
  (parent 47)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 74)
  (parent 48)
  (seen 110)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price goods-0 nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods-0)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 75)
  (parent 48)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 76)
  (parent 49)
  (seen 114)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 77)
  (parent 49)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 78)
  (parent 50)
  (seen 118)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 79)
  (parent 51)
  (seen 117 119)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 80)
  (parent 52)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 81)
  (parent 52)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 82)
  (parent 54)
  (seen 80 81)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 3))
    ((3 0) (0 0)) ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0))
    ((4 1) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 83)
  (parent 54)
  (seen 106 116)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nm price-0 acctnum goods text)
    (c hash hash-0 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (0 0))
    ((4 0) (3 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk b) (privk m))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 84)
  (parent 57)
  (seen 15)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 85)
  (parent 58)
  (seen 122)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 86)
  (parent 58)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 87)
  (parent 59)
  (seen 104 126)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 88)
  (parent 59)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 3 bank 2)
    (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-1)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 89)
  (parent 59)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 90)
  (parent 60)
  (seen 132)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum goods-0 nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 91)
  (parent 60)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (added-strand bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 92)
  (parent 61)
  (seen 114 136)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation encryption-test (displaced 5 2 bank 2)
    (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0)) (privk b-0))
    (4 3))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0))))
  (label 93)
  (parent 61)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 94)
  (parent 62)
  (seen 118 140)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 2) (4 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (4 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 95)
  (parent 63)
  (seen 119 139 141)
  (unrealized (0 0) (0 2) (1 0) (4 0) (5 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 96)
  (parent 64)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 97)
  (parent 64)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (0 0))
    ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 98)
  (parent 66)
  (seen 96 97)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 nb-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 3))
    ((3 0) (0 0)) ((3 0) (4 0)) ((3 2) (2 0)) ((3 4) (1 0))
    ((4 1) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 99)
  (parent 66)
  (seen 116 128 138)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum price (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 100)
  (parent 69)
  (seen 26)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 101)
  (parent 70)
  (seen 144)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 102)
  (parent 71)
  (seen 103 117)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-1 (5 0)
    (enc nc nb-1 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 103)
  (parent 71)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 4 customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 104)
  (parent 71)
  (seen 102 103 117)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 105)
  (parent 72)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 106)
  (parent 72)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 107)
  (parent 73)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (4 3)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 108)
  (parent 73)
  (seen 145 157)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 109)
  (parent 73)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum price (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 110)
  (parent 74)
  (seen 26)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price goods nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum nb-0) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 111)
  (parent 75)
  (seen 160)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 112)
  (parent 76)
  (seen 118 157)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-1 (5 0)
    (enc nc nb-1 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 113)
  (parent 76)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 4 customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 114)
  (parent 76)
  (seen 77 112 113 119)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 115)
  (parent 77)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 116)
  (parent 77)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 117)
  (parent 78)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 118)
  (parent 78)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 119)
  (parent 79)
  (seen 113 118)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 120)
  (parent 81)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 5 4 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 121)
  (parent 82)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 122)
  (parent 85)
  (seen 34)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((3 1) (4 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 123)
  (parent 86)
  (seen 173)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 124)
  (parent 87)
  (seen 125 139)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "4 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-1 (5 0)
    (enc nc nb-1 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 125)
  (parent 87)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 126)
  (parent 87)
  (seen 124 125 139)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 127)
  (parent 88)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 128)
  (parent 88)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 129)
  (parent 89)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (4 3)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 130)
  (parent 89)
  (seen 157 174 186)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 131)
  (parent 89)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (4 1)) ((1 1) (4 3)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 132)
  (parent 90)
  (seen 34)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum goods nb-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 3 (acctnum acctnum) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (3 0))
    ((2 2) (4 0)) ((3 1) (1 0)) ((4 1) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 133)
  (parent 91)
  (seen 189)
  (unrealized (0 2))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 134)
  (parent 92)
  (seen 140 186)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-1 (5 0)
    (enc nc nb-1 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 135)
  (parent 92)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 136)
  (parent 92)
  (seen 93 134 135 141)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 137)
  (parent 93)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 138)
  (parent 93)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 139)
  (parent 94)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 140)
  (parent 94)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 141)
  (parent 95)
  (seen 135 140)
  (unrealized (0 0) (0 2) (1 0) (4 0))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 142)
  (parent 97)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 5 4 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 143)
  (parent 98)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nm price-0 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (5 1)) ((1 1) (5 3)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 1) (0 0)) ((5 0) (4 0)) ((5 2) (2 0)) ((5 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum price (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 144)
  (parent 101)
  (seen 43)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 145)
  (parent 102)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((2 1) (5 0)) ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 146)
  (parent 102)
  (seen 117 205)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 147)
  (parent 103)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 148)
  (parent 103)
  (seen 204 210)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 149)
  (parent 104)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 150)
  (parent 104)
  (seen 117 204 213)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 151)
  (parent 105)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 152)
  (parent 105)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 153)
  (parent 106)
  (seen 151 152)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 154)
  (parent 107)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 155)
  (parent 107)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 156)
  (parent 108)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 4 customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 157)
  (parent 108)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 158)
  (parent 109)
  (seen 154 155)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (4 3)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 159)
  (parent 109)
  (seen 203 218 220)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "5 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nm price-0 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm acctnum) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb acctnum)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm acctnum) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm acctnum)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (5 1)) ((1 1) (5 3)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 1) (0 0)) ((5 0) (4 0)) ((5 2) (2 0)) ((5 2) (3 0))
    ((5 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nm acctnum)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb acctnum price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc acctnum m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb acctnum (pubk hash)) (privk m))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc acctnum acctnum price (pubk hash-0))
            (privk b)) (enc nc acctnum (pubk c)))))
    ((recv (enc c nc acctnum acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 acctnum price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc acctnum m price (pubk c)))
      (send (enc c nc acctnum acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb acctnum price (pubk hash)) (privk b))
          nb))))
  (label 160)
  (parent 111)
  (seen 43)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 161)
  (parent 112)
  (seen 117 118)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 162)
  (parent 113)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 163)
  (parent 113)
  (seen 117 227)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 2) (5 0)) ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 164)
  (parent 114)
  (seen 117 119 226)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 165)
  (parent 115)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 166)
  (parent 115)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 167)
  (parent 116)
  (seen 165 166)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 168)
  (parent 117)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 169)
  (parent 118)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (4 0)
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 170)
  (parent 119)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb price nb-0 goods nm price-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 171)
  (parent 121)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 goods-0 nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 172)
  (parent 121)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 nm price-0 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (5 1)) ((1 1) (5 3)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 1) (0 0)) ((5 0) (4 0)) ((5 2) (2 0)) ((5 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 173)
  (parent 123)
  (seen 55)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 174)
  (parent 124)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      nb-2 text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((2 1) (5 0)) ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 175)
  (parent 124)
  (seen 139 205 240)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 176)
  (parent 125)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 177)
  (parent 125)
  (seen 210 239 245)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 178)
  (parent 126)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      nb-2 text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 179)
  (parent 126)
  (seen 139 213 239 248)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 180)
  (parent 127)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 181)
  (parent 127)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 182)
  (parent 128)
  (seen 180 181)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 183)
  (parent 129)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 184)
  (parent 129)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 185)
  (parent 130)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 186)
  (parent 130)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 187)
  (parent 131)
  (seen 183 184)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 nb-1
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (4 3)) ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 188)
  (parent 131)
  (seen 220 238 253 255)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "5 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 nm price-0 acctnum goods text)
    (c hash hash-0 hash-1 b m name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (defstrand customer 5 (acctnum acctnum) (nb nb) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash))
  (precedes ((0 1) (5 1)) ((1 1) (5 3)) ((2 1) (1 0)) ((3 1) (1 0))
    ((4 1) (0 0)) ((5 0) (4 0)) ((5 2) (2 0)) ((5 2) (3 0))
    ((5 4) (0 2)))
  (non-orig (privk c) (privk hash) (privk hash-0) (privk hash-1)
    (privk b) (privk m))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand customer 5) nb (0 2)
    (enc "hash" c nc nb nb-0 price (pubk hash)) (enc nc nb (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c))))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))))
  (label 189)
  (parent 133)
  (seen 55)
  (unrealized)
  (comment "1 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      nb-2 text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 190)
  (parent 134)
  (seen 118 139 140)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))))
  (label 191)
  (parent 135)
  (unrealized (0 0) (0 2) (1 0))
  (comment "3 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 192)
  (parent 135)
  (seen 139 227 262)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      nb-2 text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (1 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 2) (5 0)) ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 193)
  (parent 136)
  (seen 119 139 141 261)
  (unrealized (0 0) (0 2) (1 0) (5 0) (6 0))
  (comment "5 in cohort - 0 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0))))
  (label 194)
  (parent 137)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 195)
  (parent 137)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 196)
  (parent 138)
  (seen 194 195)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 197)
  (parent 139)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (4 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 198)
  (parent 140)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (4 0)
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 199)
  (parent 141)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb price acctnum nb-0 goods nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 200)
  (parent 143)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars
    (nb goods price acctnum nb-0 goods-0 nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 201)
  (parent 143)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 202)
  (parent 145)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 203)
  (parent 145)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-2 (6 0)
    (enc nc nb-2 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 204)
  (parent 146)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 4 customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 205)
  (parent 146)
  (seen 210)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 206)
  (parent 147)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 207)
  (parent 147)
  (seen 282)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "6 in cohort - 4 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 208)
  (parent 147)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 2 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 209)
  (parent 148)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 4 customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 210)
  (parent 148)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 211)
  (parent 149)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 212)
  (parent 149)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum nb-0 nb-1 goods-0 acctnum-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 4 customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 213)
  (parent 150)
  (seen 117 205 210)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 214)
  (parent 152)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 6 5 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 215)
  (parent 153)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 216)
  (parent 155)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 217)
  (parent 156)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 218)
  (parent 156)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 219)
  (parent 157)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 220)
  (parent 157)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 6 5 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 221)
  (parent 158)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-2 (6 0)
    (enc nc nb-2 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 222)
  (parent 161)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 223)
  (parent 162)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 224)
  (parent 162)
  (seen 307)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 225)
  (parent 162)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 226)
  (parent 163)
  (seen 222)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 4 customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 227)
  (parent 163)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 228)
  (parent 166)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 6 5 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 229)
  (parent 167)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 230)
  (parent 168)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 231)
  (parent 168)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 232)
  (parent 169)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 233)
  (parent 169)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 234)
  (parent 170)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 235)
  (parent 170)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb price nb-0 goods nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc price-0 nm-0 m price-1 (pubk c))
    (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 236)
  (parent 172)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 237)
  (parent 174)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 238)
  (parent 174)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-2 (6 0)
    (enc nc nb-2 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 239)
  (parent 175)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      nb-2 text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 240)
  (parent 175)
  (seen 245)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "2 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 241)
  (parent 176)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 242)
  (parent 176)
  (seen 282 333)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "6 in cohort - 4 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 243)
  (parent 176)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 2 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 244)
  (parent 177)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 245)
  (parent 177)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 246)
  (parent 178)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 247)
  (parent 178)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 acctnum-1
      nb-2 text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 248)
  (parent 179)
  (seen 139 240 245)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "6 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 249)
  (parent 181)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 6 5 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 250)
  (parent 182)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 251)
  (parent 184)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 252)
  (parent 185)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 253)
  (parent 185)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 254)
  (parent 186)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 255)
  (parent 186)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 6 5 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 256)
  (parent 187)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-2 (6 0)
    (enc nc nb-2 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 257)
  (parent 190)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 258)
  (parent 191)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((0 1) (5 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 259)
  (parent 191)
  (seen 307 358)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "5 in cohort - 3 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 260)
  (parent 191)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 261)
  (parent 192)
  (seen 257)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "3 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (1 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 262)
  (parent 192)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 263)
  (parent 195)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 6 5 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 264)
  (parent 196)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 265)
  (parent 197)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 266)
  (parent 197)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 267)
  (parent 198)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 268)
  (parent 198)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 269)
  (parent 199)
  (unrealized (0 0) (0 2))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 nm price-0
      text) (b m c hash b-0 hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 270)
  (parent 199)
  (unrealized (0 0) (0 2) (1 0))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nb price acctnum nb-0 goods nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (3 3)) ((3 0) (4 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (0 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc price-0 nm-0 m price-1 (pubk c))
    (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 271)
  (parent 201)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 272)
  (parent 202)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 273)
  (parent 202)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 274)
  (parent 203)
  (seen 272 273)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 275)
  (parent 204)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 276)
  (parent 205)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods text) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 277)
  (parent 206)
  (unrealized (0 2))
  (comment "empty cohort"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 278)
  (parent 206)
  (unrealized (0 0) (0 2))
  (comment "1 in cohort - 1 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 2 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 279)
  (parent 207)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((3 1) (6 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 280)
  (parent 207)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((5 1) (6 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 5 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 281)
  (parent 207)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 4 customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 282)
  (parent 207)
  (unrealized (0 0) (0 2) (1 0))
  (comment "2 in cohort - 2 not yet seen"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 283)
  (parent 208)
  (seen 277 278)
  (unrealized (0 0) (0 2))
  (comment "4 in cohort - 1 not yet seen"))

(comment "Strand bound exceeded--aborting run")

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (7 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 284)
  (parent 208)
  (unrealized (0 0) (0 2) (1 0) (7 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 285)
  (parent 209)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 286)
  (parent 210)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 287)
  (parent 211)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 288)
  (parent 211)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 289)
  (parent 212)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 290)
  (parent 213)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 acctnum-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-1) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-1) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-1) (nc nc) (nm nb-1) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-1) (nc nc) (nm nb-1) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-1) (nb nb-1) (nc nc) (nm nb-1)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-1) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-1) (nc nc) (nm nb-1) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-1)
  (operation nonce-test (displaced 7 6 bank 2) nb-2 (5 0)
    (enc "hash" c nc nb-1 nb-2 price (pubk hash-2))
    (enc nc nb-2 m price (pubk c))
    (enc c nc nb-2 nb-2 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-1 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-1 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-1 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-1 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-1 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-1 nb-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc nb-1 nb-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-1 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-1 m price (pubk c)))
      (send (enc c nc nb-1 nb-1 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) nb-1)))
    ((recv (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc nb-1 nb-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 291)
  (parent 213)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb price nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 292)
  (parent 215)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 nb-1 goods-0 nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (0 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 293)
  (parent 215)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 294)
  (parent 217)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 295)
  (parent 217)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 296)
  (parent 218)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 297)
  (parent 219)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 298)
  (parent 219)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 299)
  (parent 220)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb price nb-0 goods nm price-0 text) (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 300)
  (parent 221)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 goods-0 nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 301)
  (parent 221)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 302)
  (parent 222)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods text) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 303)
  (parent 223)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (5 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 304)
  (parent 223)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((2 1) (5 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 305)
  (parent 224)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((4 1) (5 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 4 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 306)
  (parent 224)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 3 customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 307)
  (parent 224)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 308)
  (parent 225)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 309)
  (parent 225)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 310)
  (parent 226)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-0 nb-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 311)
  (parent 227)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb price nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 312)
  (parent 229)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 nb-1 goods-0 nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (0 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 313)
  (parent 229)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 314)
  (parent 230)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (6 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 315)
  (parent 230)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 316)
  (parent 231)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 317)
  (parent 232)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (6 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 318)
  (parent 232)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 319)
  (parent 233)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 320)
  (parent 234)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 321)
  (parent 234)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 322)
  (parent 235)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 323)
  (parent 237)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 324)
  (parent 237)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 325)
  (parent 238)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 326)
  (parent 239)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 327)
  (parent 240)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 328)
  (parent 241)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 329)
  (parent 241)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 2 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 330)
  (parent 242)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((3 1) (6 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 3 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 331)
  (parent 242)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((5 1) (6 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 7 5 bank 2) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 332)
  (parent 242)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (6 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 333)
  (parent 242)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 334)
  (parent 243)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((0 1) (7 0)) ((1 1) (0 2)) ((2 1) (3 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 335)
  (parent 243)
  (unrealized (0 0) (0 2) (1 0) (7 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 336)
  (parent 244)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 337)
  (parent 245)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 nb-1 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 338)
  (parent 246)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 339)
  (parent 246)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 340)
  (parent 247)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 nb-1 goods-0 nb-2 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c))))))
  (label 341)
  (parent 248)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 acctnum-1 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-1) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-1) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-1) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-1) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-1) (nc nc) (nm nb-1)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-1) (nc nc) (nm nb-1) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-1) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (1 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-1)
  (operation nonce-test (displaced 7 6 bank 2) nb-2 (5 0)
    (enc "hash" c nc nb-1 nb-2 price (pubk hash-2))
    (enc nc nb-2 m price (pubk c))
    (enc c nc nb-2 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-1 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-1 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-1 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-1 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-1 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-1 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-1 m price (pubk c)))
      (send (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) nb-1)))
    ((recv (enc c nc nb-1 acctnum-1 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-0))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc nb-1 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-1 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 342)
  (parent 248)
  (unrealized (0 0) (0 2) (1 0) (5 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb price acctnum nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 343)
  (parent 250)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 nm-0 price-1
      text) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (4 3))
    ((3 1) (1 0)) ((4 0) (5 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (0 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 344)
  (parent 250)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 345)
  (parent 252)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 346)
  (parent 252)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 347)
  (parent 253)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 348)
  (parent 254)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0)) ((4 4) (1 0))
    ((5 1) (1 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 349)
  (parent 254)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (0 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (5 0))
    ((4 4) (1 0)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 350)
  (parent 255)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb price acctnum nb-0 goods nm price-0 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 351)
  (parent 256)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nb goods price acctnum nb-0 goods-0 nm price-0 nm-0 price-1 text)
    (m c hash b hash-0 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (4 3))
    ((4 0) (5 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (0 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 352)
  (parent 256)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 353)
  (parent 257)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))))
  (label 354)
  (parent 258)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (5 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 355)
  (parent 258)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((2 1) (5 0))
    ((3 0) (0 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 2 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 356)
  (parent 259)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((4 1) (5 0))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (displaced 6 4 bank 2) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 357)
  (parent 259)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (added-strand customer 3) nb-0 (5 0)
    (enc nc nb-0 m price (pubk c)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 358)
  (parent 259)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 359)
  (parent 260)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nm price-0 nb-1
      text) (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((0 1) (6 0)) ((1 1) (0 2)) ((2 1) (4 0))
    ((3 0) (0 0)) ((3 0) (5 0)) ((3 2) (2 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (1 0)) ((6 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand bank 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc nc nm m price-0 (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 360)
  (parent 260)
  (unrealized (0 0) (0 2) (1 0) (6 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 361)
  (parent 261)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum acctnum-0 nb-0 goods-0 nb-1 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (acctnum-1 acctnum-0)) nb-0 (5 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-0 m price (pubk c))
    (enc c nc nb-0 acctnum-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c))))))
  (label 362)
  (parent 262)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb price acctnum nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 2) (2 0)) ((4 2) (3 0)) ((4 4) (1 0))
    ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (contracted (goods-0 goods)) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c)) (enc c price-0 goods (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 363)
  (parent 264)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nb goods price acctnum nb-0 nb-1 goods-0 nm price-0 nm-0 price-1
      text) (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc price-0)
    (nm nb-0) (goods goods-0) (price price) (b b) (c c) (m m)
    (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (defstrand merchant 2 (nc price-0) (nm nm-0) (goods goods-0)
    (price price-1) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (4 3)) ((3 1) (1 0))
    ((4 0) (5 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 2) (3 0))
    ((4 4) (1 0)) ((5 1) (0 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0 nm-0)
  (operation nonce-test (added-strand merchant 2) price-0 (0 0)
    (enc price-0 nm m price-0 (pubk c))
    (enc c price-0 goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm-0 m price-1 (pubk c)))))
  (label 364)
  (parent 264)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 365)
  (parent 265)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (6 0))
    ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3)) ((5 1) (4 0))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 366)
  (parent 265)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (5 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 367)
  (parent 266)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 368)
  (parent 267)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (6 0))
    ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0)) ((4 1) (3 3))
    ((5 1) (4 0)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 369)
  (parent 267)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (3 1)) ((1 1) (0 2)) ((2 1) (4 0)) ((3 0) (0 0))
    ((3 0) (6 0)) ((3 2) (2 0)) ((3 2) (5 0)) ((3 4) (1 0))
    ((4 1) (3 3)) ((5 1) (4 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 370)
  (parent 268)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price acctnum nb-0 goods nb-1 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 371)
  (parent 269)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (5 0)) ((2 2) (4 0))
    ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0)) ((5 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 372)
  (parent 269)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand customer 5 (acctnum acctnum) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (2 1)) ((1 1) (0 2)) ((2 0) (0 0)) ((2 0) (5 0))
    ((2 2) (4 0)) ((2 4) (1 0)) ((3 1) (2 3)) ((4 1) (3 0))
    ((5 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (b-0 b) (acctnum-0 acctnum)) nc
    (1 0) (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc nc nm m price-0 (pubk c))
    (enc c nc goods-0 (pubk m)) (enc c nc nb-0 acctnum price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 acctnum price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 373)
  (parent 270)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 nb-1 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 374)
  (parent 273)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 nb-1 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 7 6 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-1 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 375)
  (parent 274)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (5 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 376)
  (parent 275)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (6 0))
    ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (5 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 377)
  (parent 275)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 nb-1 goods-0 nb-2 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c)) (enc nc nb-2 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-2 (pubk c))))))
  (label 378)
  (parent 276)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars
    (nc nb goods price acctnum nb-0 nb-1 goods-0 nb-2 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-2)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (5 0))
    ((3 1) (1 0)) ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0))
    ((4 2) (6 0)) ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (5 0))
    ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c)) (enc nc nb-2 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-2 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-2 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 379)
  (parent 276)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb price nb-0 goods nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (contracted (goods-0 goods)) nc (0 0)
    (enc nc nm m price-0 (pubk c)) (enc c nc goods (pubk m)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 380)
  (parent 278)
  (unrealized (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 381)
  (parent 279)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((2 1) (6 0))
    ((3 1) (5 0)) ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 382)
  (parent 279)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((3 1) (6 0)) ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 383)
  (parent 280)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((3 1) (6 0)) ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 384)
  (parent 280)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((5 1) (6 0)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 385)
  (parent 281)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((5 1) (6 0)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 386)
  (parent 281)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price nb-0 goods-0 nb-1 text)
    (m c hash b hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b) (c c) (hash hash-2))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 2) (2 0)) ((4 2) (6 0)) ((4 4) (1 0))
    ((5 1) (4 3)) ((6 1) (1 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0)
  (operation nonce-test (contracted (b-0 b) (acctnum nb-0)) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b)) (enc nc nb-1 (pubk c))))))
  (label 387)
  (parent 282)
  (unrealized (0 0) (0 2))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nc nb goods price acctnum nb-0 goods-0 nb-1 nm price-0 text)
    (b m c hash b-0 hash-0 hash-1 hash-2 name))
  (defstrand merchant 4 (nb nb) (nc nc) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum acctnum) (nc nc) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc nc) (nm nb-0)
    (goods goods-0) (price price) (b b-0) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-0)
    (price price) (b b-0) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc nc) (nm nb-0) (nb nb-1)
    (price price) (b b-0) (c c) (hash hash-2))
  (defstrand merchant 2 (nc nc) (nm nm) (goods goods-0) (price price-0)
    (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (0 0)) ((4 0) (7 0)) ((4 2) (2 0)) ((4 2) (6 0))
    ((4 4) (1 0)) ((5 1) (4 3)) ((6 1) (1 0)) ((7 1) (1 0)))
  (non-orig (privk b) (privk m) (privk c) (privk hash) (privk b-0)
    (privk hash-0) (privk hash-1) (privk hash-2))
  (uniq-orig nc nb nb-0 nm)
  (operation nonce-test (added-strand merchant 2) nc (1 0)
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
    (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
    (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
    (enc nc nb-0 (pubk c)) (enc nc nb-1 (pubk c))
    (enc nc nb-0 m price (pubk c)) (enc c nc goods-0 (pubk m))
    (enc c nc nb-0 nb-0 price (pubk b-0)))
  (traces
    ((recv (enc c nc goods (pubk m)))
      (send (enc nc nb-0 m price (pubk c)))
      (recv
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c nc nb-0 acctnum price (pubk b)))
      (send
        (cat (enc (enc "hash" c nc nb nb-0 price (pubk hash)) (privk b))
          (enc nc nb (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-1))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((send (enc c nc goods-0 (pubk m)))
      (recv (enc nc nb-0 m price (pubk c)))
      (send (enc c nc nb-0 nb-0 price (pubk b-0)))
      (recv
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) nb-0)))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-0 nb-0 price (pubk hash-0))
            (privk b-0)) (enc nc nb-0 (pubk c)))))
    ((recv (enc c nc nb-0 nb-0 price (pubk b-0)))
      (send
        (cat
          (enc (enc "hash" c nc nb-1 nb-0 price (pubk hash-2))
            (privk b-0)) (enc nc nb-1 (pubk c)))))
    ((recv (enc c nc goods-0 (pubk m)))
      (send (enc nc nm m price-0 (pubk c)))))
  (label 388)
  (parent 282)
  (unrealized (0 0) (0 2) (1 0))
  (comment "aborted"))

(defskeleton epmo_acctnum
  (vars (nb goods price nb-0 goods-0 nm price-0 text)
    (m c hash b hash-0 hash-1 name))
  (defstrand merchant 4 (nb nb) (nc price-0) (nm nb-0) (goods goods)
    (price price) (b b) (c c) (m m) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb)
    (price price) (b b) (c c) (hash hash))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-1))
  (defstrand customer 5 (acctnum nb-0) (nb nb-0) (nc price-0) (nm nb-0)
    (goods goods-0) (price price) (b b) (c c) (m m) (hash hash-0))
  (defstrand bank 2 (acctnum nb-0) (nc price-0) (nm nb-0) (nb nb-0)
    (price price) (b b) (c c) (hash hash-0))
  (defstrand merchant 2 (nc price-0) (nm nm) (goods goods-0)
    (price price-0) (c c) (m m))
  (precedes ((0 1) (4 1)) ((1 1) (0 2)) ((2 1) (3 0)) ((3 1) (5 0))
    ((4 0) (6 0)) ((4 2) (2 0)) ((4 4) (1 0)) ((5 1) (4 3))
    ((6 1) (0 0)))
  (non-orig (privk m) (privk c) (privk hash) (privk b) (privk hash-0)
    (privk hash-1))
  (uniq-orig nb nb-0 nm price-0)
  (operation nonce-test (displaced 7 6 merchant 2) nc (0 0)
    (enc c nc goods-0 (pubk m)))
  (traces
    ((recv (enc c price-0 goods (pubk m)))
      (send (enc price-0 nb-0 m price (pubk c)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) nb))
      (send (enc (enc "hash" b m nb nb-0 (pubk hash)) (privk m))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb nb-0 price (pubk hash))
            (privk b)) (enc price-0 nb (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-1))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((send (enc c price-0 goods-0 (pubk m)))
      (recv (enc price-0 nb-0 m price (pubk c)))
      (send (enc c price-0 nb-0 nb-0 price (pubk b)))
      (recv
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c))))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) nb-0)))
    ((recv (enc c price-0 nb-0 nb-0 price (pubk b)))
      (send
        (cat
          (enc (enc "hash" c price-0 nb-0 nb-0 price (pubk hash-0))
            (privk b)) (enc price-0 nb-0 (pubk c)))))
    ((recv (enc c price-0 goods-0 (pubk m)))
      (send (enc price-0 nm m price-0 (pubk c)))))
  (label 389)
  (parent 283)
  (unrealized (0 0) (0 2))
  (comment "aborted"))
